@@ -1045,9 +1045,23 @@ power_manager_button_press_event (GtkWidget *widget, GdkEventButton *event)
 {
     PowerManagerButton *button = POWER_MANAGER_BUTTON (widget);
 
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
-    power_manager_button_show_menu (button);
-    return TRUE;
+    if (event->button == 1 && !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
+    {
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
+      power_manager_button_show_menu (button);
+      return TRUE;
+    }
+
+    if (event->button == 2)
+    {
+      gboolean state;
+
+      state = xfconf_channel_get_bool (button->priv->channel, XFPM_PROPERTIES_PREFIX PRESENTATION_MODE, FALSE);
+      xfconf_channel_set_bool (button->priv->channel, XFPM_PROPERTIES_PREFIX PRESENTATION_MODE, !state);
+      return TRUE;
+    }
+
+    return FALSE;
 }
 
 #ifdef XFCE_PLUGIN
@@ -1113,19 +1127,13 @@ power_manager_button_free_data_cb (XfcePanelPlugin *plugin, PowerManagerButton *
 {
     gtk_widget_destroy (GTK_WIDGET (button));
 }
-#endif
-
-static void
-help_cb (GtkMenuItem *menuitem, gpointer user_data)
-{
-    xfce_dialog_show_help_with_version (NULL, "xfce4-power-manager", "start", NULL, XFPM_VERSION_SHORT);
-}
 
 static void
 about_cb (GtkMenuItem *menuitem, gpointer user_data)
 {
-    xfpm_about ("xfce4-power-manager");
+  xfpm_about ("xfce4-power-manager");
 }
+#endif
 
 void
 power_manager_button_show (PowerManagerButton *button)
@@ -1148,20 +1156,9 @@ power_manager_button_show (PowerManagerButton *button)
 
     gtk_container_add (GTK_CONTAINER (button), GTK_WIDGET (hbox));
 
-    /* help dialog */
-    mi = gtk_menu_item_new_with_mnemonic (_("_Help"));
-    gtk_widget_set_sensitive (mi, TRUE);
-    gtk_widget_show (mi);
-    g_signal_connect (mi, "activate", G_CALLBACK (help_cb), button);
-
-    /* about dialog */
-    mi = gtk_menu_item_new_with_mnemonic (_("_About"));
-    gtk_widget_set_sensitive (mi, TRUE);
-    gtk_widget_show (mi);
-    g_signal_connect (mi, "activate", G_CALLBACK (about_cb), button);
-
 #ifdef XFCE_PLUGIN
-    xfce_panel_plugin_menu_insert_item (button->priv->plugin, GTK_MENU_ITEM (mi));
+    xfce_panel_plugin_menu_show_about (button->priv->plugin);
+    g_signal_connect (button->priv->plugin, "about", G_CALLBACK (about_cb), NULL);
 
     g_signal_connect (button->priv->plugin, "size-changed",
                       G_CALLBACK (power_manager_button_size_changed_cb), button);
