@@ -26,9 +26,6 @@
 #ifdef XFCE_PLUGIN
 #include <libxfce4panel/xfce-panel-plugin.h>
 #endif
-#ifdef LXDE_PLUGIN
-#include <lxpanel/plugin.h>
-#endif
 
 G_BEGIN_DECLS
 
@@ -49,6 +46,9 @@ typedef struct
 {
     GtkToggleButtonClass parent_class;
 
+    /*< Signals >*/
+    void (*tooltip_changed)  (PowerManagerButton *button);
+    void (*icon_name_changed)(PowerManagerButton *button);
 } PowerManagerButtonClass;
 
 GType                    power_manager_button_get_type (void) G_GNUC_CONST;
@@ -56,13 +56,16 @@ GType                    power_manager_button_get_type (void) G_GNUC_CONST;
 #ifdef XFCE_PLUGIN
 GtkWidget               *power_manager_button_new       (XfcePanelPlugin *plugin);
 #endif
-#ifdef LXDE_PLUGIN
+#ifdef XFPM_SYSTRAY
 GtkWidget               *power_manager_button_new       (void);
 #endif
 
 void                     power_manager_button_show      (PowerManagerButton *button);
 
-void                     power_manager_button_set_width (PowerManagerButton *button, gint width);
+void                     power_manager_button_show_menu (PowerManagerButton *button);
+
+const gchar             *power_manager_button_get_icon_name (PowerManagerButton *button);
+const gchar             *power_manager_button_get_tooltip   (PowerManagerButton *button);
 
 G_END_DECLS
 
