@@ -1,5 +1,6 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
+ * * Copyright (C) 2019 Kacper Piwiński
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -61,9 +62,6 @@ static void xfpm_backlight_set_property (GObject *object,
 
 #define ALARM_DISABLED 9
 
-#define XFPM_BACKLIGHT_GET_PRIVATE(o) \
-(G_TYPE_INSTANCE_GET_PRIVATE ((o), XFPM_TYPE_BACKLIGHT, XfpmBacklightPrivate))
-
 struct XfpmBacklightPrivate
 {
     XfpmBrightness *brightness;
@@ -97,7 +95,7 @@ enum
     N_PROPERTIES
 };
 
-G_DEFINE_TYPE (XfpmBacklight, xfpm_backlight, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (XfpmBacklight, xfpm_backlight, G_TYPE_OBJECT)
 
 
 static void
@@ -326,14 +324,12 @@ xfpm_backlight_class_init (XfpmBacklightClass *klass)
                                                        1,
                                                        -1,
                                                        G_PARAM_READWRITE));
-
-    g_type_class_add_private (klass, sizeof (XfpmBacklightPrivate));
 }
 
 static void
 xfpm_backlight_init (XfpmBacklight *backlight)
 {
-    backlight->priv = XFPM_BACKLIGHT_GET_PRIVATE (backlight);
+    backlight->priv = xfpm_backlight_get_instance_private (backlight);
 
     backlight->priv->brightness = xfpm_brightness_new ();
     backlight->priv->has_hw     = xfpm_brightness_setup (backlight->priv->brightness);
@@ -365,7 +361,7 @@ xfpm_backlight_init (XfpmBacklight *backlight)
 	backlight->priv->brightness_switch = -1;
 
 	xfconf_g_property_bind (xfpm_xfconf_get_channel(backlight->priv->conf),
-							PROPERTIES_PREFIX BRIGHTNESS_SWITCH, G_TYPE_INT,
+							XFPM_PROPERTIES_PREFIX BRIGHTNESS_SWITCH, G_TYPE_INT,
 							G_OBJECT(backlight), BRIGHTNESS_SWITCH);
 
 	ret = xfpm_brightness_get_switch (backlight->priv->brightness,
@@ -386,13 +382,13 @@ xfpm_backlight_init (XfpmBacklight *backlight)
 	 */
 	backlight->priv->brightness_switch_save =
 		xfconf_channel_get_int (xfpm_xfconf_get_channel(backlight->priv->conf),
-								PROPERTIES_PREFIX BRIGHTNESS_SWITCH_SAVE,
+								XFPM_PROPERTIES_PREFIX BRIGHTNESS_SWITCH_SAVE,
 								-1);
 
 	if (backlight->priv->brightness_switch_save == -1)
 	{
 	if (!xfconf_channel_set_int (xfpm_xfconf_get_channel(backlight->priv->conf),
-								 PROPERTIES_PREFIX BRIGHTNESS_SWITCH_SAVE,
+								 XFPM_PROPERTIES_PREFIX BRIGHTNESS_SWITCH_SAVE,
 								 backlight->priv->brightness_switch))
 	g_critical ("Cannot set value for property %s\n", BRIGHTNESS_SWITCH_SAVE);
 
@@ -407,7 +403,7 @@ xfpm_backlight_init (XfpmBacklight *backlight)
 
     /* check whether to change the brightness switch */
 	handle_keys = xfconf_channel_get_bool (xfpm_xfconf_get_channel(backlight->priv->conf),
-										   PROPERTIES_PREFIX HANDLE_BRIGHTNESS_KEYS,
+										   XFPM_PROPERTIES_PREFIX HANDLE_BRIGHTNESS_KEYS,
 										   TRUE);
 	backlight->priv->brightness_switch = handle_keys ? 0 : 1;
 	g_object_set (G_OBJECT (backlight),
@@ -518,7 +514,7 @@ xfpm_backlight_finalize (GObject *object)
                                     backlight->priv->brightness_switch_save);
     /* unset the xfconf saved value after the restore */
     if (!xfconf_channel_set_int (xfpm_xfconf_get_channel(backlight->priv->conf),
-                                 PROPERTIES_PREFIX BRIGHTNESS_SWITCH_SAVE, -1))
+                                 XFPM_PROPERTIES_PREFIX BRIGHTNESS_SWITCH_SAVE, -1))
     g_critical ("Cannot set value for property %s\n", BRIGHTNESS_SWITCH_SAVE);
 
     if (ret)
