@@ -45,31 +45,28 @@
 
 static void xfpm_dpms_finalize   (GObject *object);
 
-#define XFPM_DPMS_GET_PRIVATE(o) \
-(G_TYPE_INSTANCE_GET_PRIVATE((o), XFPM_TYPE_DPMS, XfpmDpmsPrivate))
-
 struct XfpmDpmsPrivate
 {
     XfpmXfconf      *conf;
 
     gboolean         dpms_capable;
     gboolean         inhibited;
-    
+
     gboolean         on_battery;
-    
+
     gulong	     switch_off_timeout_id;
     gulong	     switch_on_timeout_id;
 };
 
-G_DEFINE_TYPE (XfpmDpms, xfpm_dpms, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (XfpmDpms, xfpm_dpms, G_TYPE_OBJECT)
 
 static void
 xfpm_dpms_set_timeouts (XfpmDpms *dpms, guint16 standby, guint16 suspend, guint off)
 {
     CARD16 x_standby = 0 , x_suspend = 0, x_off = 0;
-    
+
     DPMSGetTimeouts (gdk_x11_get_default_xdisplay(), &x_standby, &x_suspend, &x_off);
-    
+
     if ( standby != x_standby || suspend != x_suspend || off != x_off )
     {
 	XFPM_DEBUG ("Settings dpms: standby=%d suspend=%d off=%d\n", standby, suspend, off);
@@ -87,10 +84,10 @@ xfpm_dpms_disable (XfpmDpms *dpms)
 {
     BOOL state;
     CARD16 power_level;
-    
+
     if (!DPMSInfo (gdk_x11_get_default_xdisplay(), &power_level, &state) )
 	g_warning ("Cannot get DPMSInfo");
-	
+
     if ( state )
 	DPMSDisable (gdk_x11_get_default_xdisplay());
 }
@@ -103,10 +100,10 @@ xfpm_dpms_enable (XfpmDpms *dpms)
 {
     BOOL state;
     CARD16 power_level;
-    
+
     if (!DPMSInfo (gdk_x11_get_default_xdisplay(), &power_level, &state) )
 	g_warning ("Cannot get DPMSInfo");
-	
+
     if ( !state )
 	DPMSEnable (gdk_x11_get_default_xdisplay());
 }
@@ -123,16 +120,16 @@ static void
 xfpm_dpms_get_sleep_mode (XfpmDpms *dpms, gboolean *ret_standby_mode)
 {
     gchar *sleep_mode;
-    
+
     g_object_get (G_OBJECT (dpms->priv->conf),
 		  DPMS_SLEEP_MODE, &sleep_mode,
 		  NULL);
-    
+
     if ( !g_strcmp0 (sleep_mode, "Standby"))
 	*ret_standby_mode = TRUE;
     else
 	*ret_standby_mode = FALSE;
-	
+
     g_free (sleep_mode);
 }
 
@@ -140,12 +137,12 @@ static void
 xfpm_dpms_get_configuration_timeouts (XfpmDpms *dpms, guint16 *ret_sleep, guint16 *ret_off )
 {
     guint sleep_time, off_time;
-    
+
     g_object_get (G_OBJECT (dpms->priv->conf),
 		  dpms->priv->on_battery ? ON_BATT_DPMS_SLEEP : ON_AC_DPMS_SLEEP, &sleep_time,
 		  dpms->priv->on_battery ? ON_BATT_DPMS_OFF : ON_AC_DPMS_OFF, &off_time,
 		  NULL);
-		  
+
     *ret_sleep = sleep_time * 60;
     *ret_off =  off_time * 60;
 }
@@ -163,9 +160,9 @@ xfpm_dpms_refresh (XfpmDpms *dpms)
         xfpm_dpms_disable (dpms);
         return;
     }
-    
+
     xfpm_dpms_get_enabled (dpms, &enabled);
-    
+
     if ( !enabled )
     {
         xfpm_dpms_disable (dpms);
@@ -178,14 +175,14 @@ xfpm_dpms_refresh (XfpmDpms *dpms)
 
     if (sleep_mode == TRUE )
     {
-	xfpm_dpms_set_timeouts	   (dpms, 
+	xfpm_dpms_set_timeouts	   (dpms,
 				    sleep_timeout,
 				    0,
 				    off_timeout);
     }
     else
     {
-	xfpm_dpms_set_timeouts     (dpms, 
+	xfpm_dpms_set_timeouts     (dpms,
 				    0,
 				    sleep_timeout,
 				    off_timeout );
@@ -206,10 +203,8 @@ static void
 xfpm_dpms_class_init(XfpmDpmsClass *klass)
 {
     GObjectClass *object_class = G_OBJECT_CLASS(klass);
-    
-    object_class->finalize = xfpm_dpms_finalize;
 
-    g_type_class_add_private(klass,sizeof(XfpmDpmsPrivate));
+    object_class->finalize = xfpm_dpms_finalize;
 }
 
 /*
@@ -218,8 +213,8 @@ xfpm_dpms_class_init(XfpmDpmsClass *klass)
 static void
 xfpm_dpms_init(XfpmDpms *dpms)
 {
-    dpms->priv = XFPM_DPMS_GET_PRIVATE(dpms);
-    
+    dpms->priv = xfpm_dpms_get_instance_private(dpms);
+
     dpms->priv->dpms_capable = DPMSCapable (gdk_x11_get_default_xdisplay());
     dpms->priv->switch_off_timeout_id = 0;
     dpms->priv->switch_on_timeout_id = 0;
@@ -245,7 +240,7 @@ xfpm_dpms_finalize(GObject *object)
     XfpmDpms *dpms;
 
     dpms = XFPM_DPMS (object);
-    
+
     g_object_unref (dpms->priv->conf);
 
     G_OBJECT_CLASS(xfpm_dpms_parent_class)->finalize(object);
@@ -255,7 +250,7 @@ XfpmDpms *
 xfpm_dpms_new (void)
 {
     static gpointer xfpm_dpms_object = NULL;
-    
+
     if ( G_LIKELY (xfpm_dpms_object != NULL ) )
     {
 	g_object_ref (xfpm_dpms_object);
@@ -265,14 +260,14 @@ xfpm_dpms_new (void)
 	xfpm_dpms_object = g_object_new (XFPM_TYPE_DPMS, NULL);
 	g_object_add_weak_pointer (xfpm_dpms_object, &xfpm_dpms_object);
     }
-    
+
     return XFPM_DPMS (xfpm_dpms_object);
 }
 
 gboolean xfpm_dpms_capable (XfpmDpms *dpms)
 {
     g_return_val_if_fail (XFPM_IS_DPMS(dpms), FALSE);
-    
+
     return dpms->priv->dpms_capable;
 }
 
@@ -280,12 +275,12 @@ void xfpm_dpms_force_level (XfpmDpms *dpms, CARD16 level)
 {
     CARD16 current_level;
     BOOL current_state;
-    
+
     XFPM_DEBUG ("start");
-    
+
     if ( !dpms->priv->dpms_capable )
 	goto out;
-    
+
     if ( G_UNLIKELY (!DPMSInfo (gdk_x11_get_default_xdisplay (), &current_level, &current_state)) )
     {
 	g_warning ("Cannot get DPMSInfo");
@@ -301,7 +296,7 @@ void xfpm_dpms_force_level (XfpmDpms *dpms, CARD16 level)
     if ( current_level != level )
     {
 	XFPM_DEBUG ("Forcing DPMS mode %d", level);
-	
+
 	if ( !DPMSForceLevel (gdk_x11_get_default_xdisplay (), level ) )
 	{
 	    g_warning ("Cannot set Force DPMS level %d", level);
@@ -315,7 +310,7 @@ void xfpm_dpms_force_level (XfpmDpms *dpms, CARD16 level)
     {
 	XFPM_DEBUG ("No need to change DPMS mode, current_level=%d requested_level=%d", current_level, level);
     }
-    
+
     out:
 	;
 }
@@ -334,7 +329,7 @@ xfpm_dpms_inhibit (XfpmDpms *dpms, gboolean inhibit)
 
     dpms->priv->inhibited = inhibit;
     xfpm_dpms_refresh (dpms);
-    XFPM_DEBUG ("dpms inhibited %s", inhibit ? "TURE" : "FALSE");
+    XFPM_DEBUG ("dpms inhibited %s", inhibit ? "TRUE" : "FALSE");
 }
 
 void
@@ -345,5 +340,5 @@ xfpm_dpms_set_on_battery (XfpmDpms *dpms, gboolean on_battery)
 
     dpms->priv->on_battery = on_battery;
     xfpm_dpms_refresh (dpms);
-    XFPM_DEBUG ("dpms on battery %s", on_battery ? "TURE" : "FALSE");
+    XFPM_DEBUG ("dpms on battery %s", on_battery ? "TRUE" : "FALSE");
 }
