@@ -23,49 +23,54 @@
 #endif
 
 #include <glib.h>
-#include <dbus/dbus-glib.h>
+#include <gio/gio.h>
 
 #include "xfpm-network-manager.h"
 
 /*
- * Inform the Network Manager when we do suspend/hibernate 
- * message is either "wake" or "sleep"
+ * Inform the Network Manager when we do suspend/hibernate
  */
-gboolean 	xfpm_send_message_to_network_manager  	(const gchar *message)
+gboolean 	xfpm_network_manager_sleep  	(gboolean sleep)
 {
 #ifdef WITH_NETWORK_MANAGER
 
-    DBusGConnection *bus   = NULL;
-    DBusGProxy      *proxy = NULL;
+    GDBusConnection *bus   = NULL;
+    GDBusProxy      *proxy = NULL;
     GError          *error = NULL;
-    
-    bus = dbus_g_bus_get ( DBUS_BUS_SYSTEM, &error);
-    
+
+    bus = g_bus_get_sync ( G_BUS_TYPE_SYSTEM, NULL, &error);
+
     if ( error )
     {
 	g_warning("%s", error->message);
 	g_error_free (error);
 	return FALSE;
     }
-    
-    proxy = dbus_g_proxy_new_for_name (bus,
-				       "org.freedesktop.NetworkManager",
-				       "/org/freedesktop/NetworkManager",
-				       "org.freedesktop.NetworkManager");
-				       
+
+    proxy = g_dbus_proxy_new_sync (bus,
+				   G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES |
+				   G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS,
+				   NULL,
+				   "org.freedesktop.NetworkManager",
+				   "/org/freedesktop/NetworkManager",
+				   "org.freedesktop.NetworkManager",
+				   NULL,
+				   NULL);
+
     if (!proxy)
     {
 	g_warning ("Failed to create proxy for Network Manager interface");
 	return FALSE;
     }
-    
-    dbus_g_proxy_call_no_reply (proxy, message, G_TYPE_INVALID);
+
+    g_dbus_proxy_call (proxy, "Sleep", g_variant_new("(b)", sleep),
+                       G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL, NULL);
     g_object_unref (G_OBJECT(proxy));
-    dbus_g_connection_unref (bus);
-    
+    g_object_unref (bus);
+
     /* Sleep 0.5 second to allow the nm applet to disconnect*/
     g_usleep (500000);
-    
+
 #endif /* WITH_NETWORK_MANAGER */
     return TRUE;
 }
